logging

package
v1.3.44 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Overview

Package logging provides primitives to interact with the openapi HTTP API.

Code generated by github.com/oapi-codegen/oapi-codegen/v2 version v2.6.0 DO NOT EDIT.

Index

Constants

const (
	HTTPBearerScopes = "HTTPBearer.Scopes"
)

Variables

This section is empty.

Functions

func NewBulkRegisterLoggersRequestWithApplicationVndAPIPlusJSONBody added in v1.3.42

func NewBulkRegisterLoggersRequestWithApplicationVndAPIPlusJSONBody(server string, body BulkRegisterLoggersApplicationVndAPIPlusJSONRequestBody) (*http.Request, error)

NewBulkRegisterLoggersRequestWithApplicationVndAPIPlusJSONBody calls the generic BulkRegisterLoggers builder with application/vnd.api+json body

func NewBulkRegisterLoggersRequestWithBody added in v1.2.6

func NewBulkRegisterLoggersRequestWithBody(server string, contentType string, body io.Reader) (*http.Request, error)

NewBulkRegisterLoggersRequestWithBody generates requests for BulkRegisterLoggers with any type of body

func NewCreateLogGroupRequestWithApplicationVndAPIPlusJSONBody added in v1.3.42

func NewCreateLogGroupRequestWithApplicationVndAPIPlusJSONBody(server string, body CreateLogGroupApplicationVndAPIPlusJSONRequestBody) (*http.Request, error)

NewCreateLogGroupRequestWithApplicationVndAPIPlusJSONBody calls the generic CreateLogGroup builder with application/vnd.api+json body

func NewCreateLogGroupRequestWithBody added in v1.2.6

func NewCreateLogGroupRequestWithBody(server string, contentType string, body io.Reader) (*http.Request, error)

NewCreateLogGroupRequestWithBody generates requests for CreateLogGroup with any type of body

func NewDeleteLogGroupRequest added in v1.2.6

func NewDeleteLogGroupRequest(server string, id string) (*http.Request, error)

NewDeleteLogGroupRequest generates requests for DeleteLogGroup

func NewDeleteLoggerRequest

func NewDeleteLoggerRequest(server string, id string) (*http.Request, error)

NewDeleteLoggerRequest generates requests for DeleteLogger

func NewGetLogGroupRequest added in v1.2.6

func NewGetLogGroupRequest(server string, id string) (*http.Request, error)

NewGetLogGroupRequest generates requests for GetLogGroup

func NewGetLoggerRequest

func NewGetLoggerRequest(server string, id string) (*http.Request, error)

NewGetLoggerRequest generates requests for GetLogger

func NewListAllLoggerSourcesRequest added in v1.3.42

func NewListAllLoggerSourcesRequest(server string, params *ListAllLoggerSourcesParams) (*http.Request, error)

NewListAllLoggerSourcesRequest generates requests for ListAllLoggerSources

func NewListLogGroupsRequest added in v1.2.6

func NewListLogGroupsRequest(server string) (*http.Request, error)

NewListLogGroupsRequest generates requests for ListLogGroups

func NewListLoggerSourceServicesRequest added in v1.3.44

func NewListLoggerSourceServicesRequest(server string) (*http.Request, error)

NewListLoggerSourceServicesRequest generates requests for ListLoggerSourceServices

func NewListLoggerSourcesRequest added in v1.3.42

func NewListLoggerSourcesRequest(server string, id string) (*http.Request, error)

NewListLoggerSourcesRequest generates requests for ListLoggerSources

func NewListLoggersRequest

func NewListLoggersRequest(server string, params *ListLoggersParams) (*http.Request, error)

NewListLoggersRequest generates requests for ListLoggers

func NewListLoggingUsageRequest added in v1.3.42

func NewListLoggingUsageRequest(server string, params *ListLoggingUsageParams) (*http.Request, error)

NewListLoggingUsageRequest generates requests for ListLoggingUsage

func NewUpdateLogGroupRequestWithApplicationVndAPIPlusJSONBody added in v1.3.42

func NewUpdateLogGroupRequestWithApplicationVndAPIPlusJSONBody(server string, id string, body UpdateLogGroupApplicationVndAPIPlusJSONRequestBody) (*http.Request, error)

NewUpdateLogGroupRequestWithApplicationVndAPIPlusJSONBody calls the generic UpdateLogGroup builder with application/vnd.api+json body

func NewUpdateLogGroupRequestWithBody added in v1.2.6

func NewUpdateLogGroupRequestWithBody(server string, id string, contentType string, body io.Reader) (*http.Request, error)

NewUpdateLogGroupRequestWithBody generates requests for UpdateLogGroup with any type of body

func NewUpdateLoggerRequestWithApplicationVndAPIPlusJSONBody added in v1.3.42

func NewUpdateLoggerRequestWithApplicationVndAPIPlusJSONBody(server string, id string, body UpdateLoggerApplicationVndAPIPlusJSONRequestBody) (*http.Request, error)

NewUpdateLoggerRequestWithApplicationVndAPIPlusJSONBody calls the generic UpdateLogger builder with application/vnd.api+json body

func NewUpdateLoggerRequestWithBody

func NewUpdateLoggerRequestWithBody(server string, id string, contentType string, body io.Reader) (*http.Request, error)

NewUpdateLoggerRequestWithBody generates requests for UpdateLogger with any type of body

Types

type BulkRegisterLoggersApplicationVndAPIPlusJSONRequestBody added in v1.3.42

type BulkRegisterLoggersApplicationVndAPIPlusJSONRequestBody = LoggerBulkRequest

BulkRegisterLoggersApplicationVndAPIPlusJSONRequestBody defines body for BulkRegisterLoggers for application/vnd.api+json ContentType.

type BulkRegisterLoggersResponse added in v1.2.6

type BulkRegisterLoggersResponse struct {
	Body                     []byte
	HTTPResponse             *http.Response
	ApplicationvndApiJSON200 *LoggerBulkResponse
	ApplicationvndApiJSON400 *ErrorResponse
	ApplicationvndApiJSON401 *ErrorResponse
	ApplicationvndApiJSON404 *ErrorResponse
	ApplicationvndApiJSON429 *ErrorResponse
}

func ParseBulkRegisterLoggersResponse added in v1.2.6

func ParseBulkRegisterLoggersResponse(rsp *http.Response) (*BulkRegisterLoggersResponse, error)

ParseBulkRegisterLoggersResponse parses an HTTP response from a BulkRegisterLoggersWithResponse call

func (BulkRegisterLoggersResponse) Status added in v1.2.6

Status returns HTTPResponse.Status

func (BulkRegisterLoggersResponse) StatusCode added in v1.2.6

func (r BulkRegisterLoggersResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type Client

type Client struct {
	// The endpoint of the server conforming to this interface, with scheme,
	// https://api.deepmap.com for example. This can contain a path relative
	// to the server, such as https://api.deepmap.com/dev-test, and all the
	// paths in the swagger spec will be appended to the server.
	Server string

	// Doer for performing requests, typically a *http.Client with any
	// customized settings, such as certificate chains.
	Client HttpRequestDoer

	// A list of callbacks for modifying requests which are generated before sending over
	// the network.
	RequestEditors []RequestEditorFn
}

Client which conforms to the OpenAPI3 specification for this service.

func NewClient

func NewClient(server string, opts ...ClientOption) (*Client, error)

Creates a new Client, with reasonable defaults

func (*Client) BulkRegisterLoggersWithApplicationVndAPIPlusJSONBody added in v1.3.42

func (c *Client) BulkRegisterLoggersWithApplicationVndAPIPlusJSONBody(ctx context.Context, body BulkRegisterLoggersApplicationVndAPIPlusJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) BulkRegisterLoggersWithBody added in v1.2.6

func (c *Client) BulkRegisterLoggersWithBody(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) CreateLogGroupWithApplicationVndAPIPlusJSONBody added in v1.3.42

func (c *Client) CreateLogGroupWithApplicationVndAPIPlusJSONBody(ctx context.Context, body CreateLogGroupApplicationVndAPIPlusJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) CreateLogGroupWithBody added in v1.2.6

func (c *Client) CreateLogGroupWithBody(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) DeleteLogGroup added in v1.2.6

func (c *Client) DeleteLogGroup(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) DeleteLogger

func (c *Client) DeleteLogger(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) GetLogGroup added in v1.2.6

func (c *Client) GetLogGroup(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) GetLogger

func (c *Client) GetLogger(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) ListAllLoggerSources added in v1.3.42

func (c *Client) ListAllLoggerSources(ctx context.Context, params *ListAllLoggerSourcesParams, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) ListLogGroups added in v1.2.6

func (c *Client) ListLogGroups(ctx context.Context, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) ListLoggerSourceServices added in v1.3.44

func (c *Client) ListLoggerSourceServices(ctx context.Context, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) ListLoggerSources added in v1.3.42

func (c *Client) ListLoggerSources(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) ListLoggers

func (c *Client) ListLoggers(ctx context.Context, params *ListLoggersParams, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) ListLoggingUsage added in v1.3.42

func (c *Client) ListLoggingUsage(ctx context.Context, params *ListLoggingUsageParams, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) UpdateLogGroupWithApplicationVndAPIPlusJSONBody added in v1.3.42

func (c *Client) UpdateLogGroupWithApplicationVndAPIPlusJSONBody(ctx context.Context, id string, body UpdateLogGroupApplicationVndAPIPlusJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) UpdateLogGroupWithBody added in v1.2.6

func (c *Client) UpdateLogGroupWithBody(ctx context.Context, id string, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) UpdateLoggerWithApplicationVndAPIPlusJSONBody added in v1.3.42

func (c *Client) UpdateLoggerWithApplicationVndAPIPlusJSONBody(ctx context.Context, id string, body UpdateLoggerApplicationVndAPIPlusJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

func (*Client) UpdateLoggerWithBody

func (c *Client) UpdateLoggerWithBody(ctx context.Context, id string, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

type ClientInterface

type ClientInterface interface {
	// ListLogGroups request
	ListLogGroups(ctx context.Context, reqEditors ...RequestEditorFn) (*http.Response, error)

	// CreateLogGroupWithBody request with any body
	CreateLogGroupWithBody(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

	CreateLogGroupWithApplicationVndAPIPlusJSONBody(ctx context.Context, body CreateLogGroupApplicationVndAPIPlusJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

	// DeleteLogGroup request
	DeleteLogGroup(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetLogGroup request
	GetLogGroup(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*http.Response, error)

	// UpdateLogGroupWithBody request with any body
	UpdateLogGroupWithBody(ctx context.Context, id string, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

	UpdateLogGroupWithApplicationVndAPIPlusJSONBody(ctx context.Context, id string, body UpdateLogGroupApplicationVndAPIPlusJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

	// ListAllLoggerSources request
	ListAllLoggerSources(ctx context.Context, params *ListAllLoggerSourcesParams, reqEditors ...RequestEditorFn) (*http.Response, error)

	// ListLoggerSourceServices request
	ListLoggerSourceServices(ctx context.Context, reqEditors ...RequestEditorFn) (*http.Response, error)

	// ListLoggers request
	ListLoggers(ctx context.Context, params *ListLoggersParams, reqEditors ...RequestEditorFn) (*http.Response, error)

	// BulkRegisterLoggersWithBody request with any body
	BulkRegisterLoggersWithBody(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

	BulkRegisterLoggersWithApplicationVndAPIPlusJSONBody(ctx context.Context, body BulkRegisterLoggersApplicationVndAPIPlusJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

	// DeleteLogger request
	DeleteLogger(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*http.Response, error)

	// GetLogger request
	GetLogger(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*http.Response, error)

	// UpdateLoggerWithBody request with any body
	UpdateLoggerWithBody(ctx context.Context, id string, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*http.Response, error)

	UpdateLoggerWithApplicationVndAPIPlusJSONBody(ctx context.Context, id string, body UpdateLoggerApplicationVndAPIPlusJSONRequestBody, reqEditors ...RequestEditorFn) (*http.Response, error)

	// ListLoggerSources request
	ListLoggerSources(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*http.Response, error)

	// ListLoggingUsage request
	ListLoggingUsage(ctx context.Context, params *ListLoggingUsageParams, reqEditors ...RequestEditorFn) (*http.Response, error)
}

The interface specification for the client above.

type ClientOption

type ClientOption func(*Client) error

ClientOption allows setting custom parameters during construction

func WithBaseURL

func WithBaseURL(baseURL string) ClientOption

WithBaseURL overrides the baseURL.

func WithHTTPClient

func WithHTTPClient(doer HttpRequestDoer) ClientOption

WithHTTPClient allows overriding the default Doer, which is automatically created using http.Client. This is useful for tests.

func WithRequestEditorFn

func WithRequestEditorFn(fn RequestEditorFn) ClientOption

WithRequestEditorFn allows setting up a callback function, which will be called right before sending the request. This can be used to mutate the request.

type ClientWithResponses

type ClientWithResponses struct {
	ClientInterface
}

ClientWithResponses builds on ClientInterface to offer response payloads

func NewClientWithResponses

func NewClientWithResponses(server string, opts ...ClientOption) (*ClientWithResponses, error)

NewClientWithResponses creates a new ClientWithResponses, which wraps Client with return type handling

func (*ClientWithResponses) BulkRegisterLoggersWithApplicationVndAPIPlusJSONBodyWithResponse added in v1.3.42

func (c *ClientWithResponses) BulkRegisterLoggersWithApplicationVndAPIPlusJSONBodyWithResponse(ctx context.Context, body BulkRegisterLoggersApplicationVndAPIPlusJSONRequestBody, reqEditors ...RequestEditorFn) (*BulkRegisterLoggersResponse, error)

func (*ClientWithResponses) BulkRegisterLoggersWithBodyWithResponse added in v1.2.6

func (c *ClientWithResponses) BulkRegisterLoggersWithBodyWithResponse(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*BulkRegisterLoggersResponse, error)

BulkRegisterLoggersWithBodyWithResponse request with arbitrary body returning *BulkRegisterLoggersResponse

func (*ClientWithResponses) CreateLogGroupWithApplicationVndAPIPlusJSONBodyWithResponse added in v1.3.42

func (c *ClientWithResponses) CreateLogGroupWithApplicationVndAPIPlusJSONBodyWithResponse(ctx context.Context, body CreateLogGroupApplicationVndAPIPlusJSONRequestBody, reqEditors ...RequestEditorFn) (*CreateLogGroupResponse, error)

func (*ClientWithResponses) CreateLogGroupWithBodyWithResponse added in v1.2.6

func (c *ClientWithResponses) CreateLogGroupWithBodyWithResponse(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*CreateLogGroupResponse, error)

CreateLogGroupWithBodyWithResponse request with arbitrary body returning *CreateLogGroupResponse

func (*ClientWithResponses) DeleteLogGroupWithResponse added in v1.2.6

func (c *ClientWithResponses) DeleteLogGroupWithResponse(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*DeleteLogGroupResponse, error)

DeleteLogGroupWithResponse request returning *DeleteLogGroupResponse

func (*ClientWithResponses) DeleteLoggerWithResponse

func (c *ClientWithResponses) DeleteLoggerWithResponse(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*DeleteLoggerResponse, error)

DeleteLoggerWithResponse request returning *DeleteLoggerResponse

func (*ClientWithResponses) GetLogGroupWithResponse added in v1.2.6

func (c *ClientWithResponses) GetLogGroupWithResponse(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*GetLogGroupResponse, error)

GetLogGroupWithResponse request returning *GetLogGroupResponse

func (*ClientWithResponses) GetLoggerWithResponse

func (c *ClientWithResponses) GetLoggerWithResponse(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*GetLoggerResponse, error)

GetLoggerWithResponse request returning *GetLoggerResponse

func (*ClientWithResponses) ListAllLoggerSourcesWithResponse added in v1.3.42

func (c *ClientWithResponses) ListAllLoggerSourcesWithResponse(ctx context.Context, params *ListAllLoggerSourcesParams, reqEditors ...RequestEditorFn) (*ListAllLoggerSourcesResponse, error)

ListAllLoggerSourcesWithResponse request returning *ListAllLoggerSourcesResponse

func (*ClientWithResponses) ListLogGroupsWithResponse added in v1.2.6

func (c *ClientWithResponses) ListLogGroupsWithResponse(ctx context.Context, reqEditors ...RequestEditorFn) (*ListLogGroupsResponse, error)

ListLogGroupsWithResponse request returning *ListLogGroupsResponse

func (*ClientWithResponses) ListLoggerSourceServicesWithResponse added in v1.3.44

func (c *ClientWithResponses) ListLoggerSourceServicesWithResponse(ctx context.Context, reqEditors ...RequestEditorFn) (*ListLoggerSourceServicesResponse, error)

ListLoggerSourceServicesWithResponse request returning *ListLoggerSourceServicesResponse

func (*ClientWithResponses) ListLoggerSourcesWithResponse added in v1.3.42

func (c *ClientWithResponses) ListLoggerSourcesWithResponse(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*ListLoggerSourcesResponse, error)

ListLoggerSourcesWithResponse request returning *ListLoggerSourcesResponse

func (*ClientWithResponses) ListLoggersWithResponse

func (c *ClientWithResponses) ListLoggersWithResponse(ctx context.Context, params *ListLoggersParams, reqEditors ...RequestEditorFn) (*ListLoggersResponse, error)

ListLoggersWithResponse request returning *ListLoggersResponse

func (*ClientWithResponses) ListLoggingUsageWithResponse added in v1.3.42

func (c *ClientWithResponses) ListLoggingUsageWithResponse(ctx context.Context, params *ListLoggingUsageParams, reqEditors ...RequestEditorFn) (*ListLoggingUsageResponse, error)

ListLoggingUsageWithResponse request returning *ListLoggingUsageResponse

func (*ClientWithResponses) UpdateLogGroupWithApplicationVndAPIPlusJSONBodyWithResponse added in v1.3.42

func (c *ClientWithResponses) UpdateLogGroupWithApplicationVndAPIPlusJSONBodyWithResponse(ctx context.Context, id string, body UpdateLogGroupApplicationVndAPIPlusJSONRequestBody, reqEditors ...RequestEditorFn) (*UpdateLogGroupResponse, error)

func (*ClientWithResponses) UpdateLogGroupWithBodyWithResponse added in v1.2.6

func (c *ClientWithResponses) UpdateLogGroupWithBodyWithResponse(ctx context.Context, id string, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*UpdateLogGroupResponse, error)

UpdateLogGroupWithBodyWithResponse request with arbitrary body returning *UpdateLogGroupResponse

func (*ClientWithResponses) UpdateLoggerWithApplicationVndAPIPlusJSONBodyWithResponse added in v1.3.42

func (c *ClientWithResponses) UpdateLoggerWithApplicationVndAPIPlusJSONBodyWithResponse(ctx context.Context, id string, body UpdateLoggerApplicationVndAPIPlusJSONRequestBody, reqEditors ...RequestEditorFn) (*UpdateLoggerResponse, error)

func (*ClientWithResponses) UpdateLoggerWithBodyWithResponse

func (c *ClientWithResponses) UpdateLoggerWithBodyWithResponse(ctx context.Context, id string, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*UpdateLoggerResponse, error)

UpdateLoggerWithBodyWithResponse request with arbitrary body returning *UpdateLoggerResponse

type ClientWithResponsesInterface

type ClientWithResponsesInterface interface {
	// ListLogGroupsWithResponse request
	ListLogGroupsWithResponse(ctx context.Context, reqEditors ...RequestEditorFn) (*ListLogGroupsResponse, error)

	// CreateLogGroupWithBodyWithResponse request with any body
	CreateLogGroupWithBodyWithResponse(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*CreateLogGroupResponse, error)

	CreateLogGroupWithApplicationVndAPIPlusJSONBodyWithResponse(ctx context.Context, body CreateLogGroupApplicationVndAPIPlusJSONRequestBody, reqEditors ...RequestEditorFn) (*CreateLogGroupResponse, error)

	// DeleteLogGroupWithResponse request
	DeleteLogGroupWithResponse(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*DeleteLogGroupResponse, error)

	// GetLogGroupWithResponse request
	GetLogGroupWithResponse(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*GetLogGroupResponse, error)

	// UpdateLogGroupWithBodyWithResponse request with any body
	UpdateLogGroupWithBodyWithResponse(ctx context.Context, id string, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*UpdateLogGroupResponse, error)

	UpdateLogGroupWithApplicationVndAPIPlusJSONBodyWithResponse(ctx context.Context, id string, body UpdateLogGroupApplicationVndAPIPlusJSONRequestBody, reqEditors ...RequestEditorFn) (*UpdateLogGroupResponse, error)

	// ListAllLoggerSourcesWithResponse request
	ListAllLoggerSourcesWithResponse(ctx context.Context, params *ListAllLoggerSourcesParams, reqEditors ...RequestEditorFn) (*ListAllLoggerSourcesResponse, error)

	// ListLoggerSourceServicesWithResponse request
	ListLoggerSourceServicesWithResponse(ctx context.Context, reqEditors ...RequestEditorFn) (*ListLoggerSourceServicesResponse, error)

	// ListLoggersWithResponse request
	ListLoggersWithResponse(ctx context.Context, params *ListLoggersParams, reqEditors ...RequestEditorFn) (*ListLoggersResponse, error)

	// BulkRegisterLoggersWithBodyWithResponse request with any body
	BulkRegisterLoggersWithBodyWithResponse(ctx context.Context, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*BulkRegisterLoggersResponse, error)

	BulkRegisterLoggersWithApplicationVndAPIPlusJSONBodyWithResponse(ctx context.Context, body BulkRegisterLoggersApplicationVndAPIPlusJSONRequestBody, reqEditors ...RequestEditorFn) (*BulkRegisterLoggersResponse, error)

	// DeleteLoggerWithResponse request
	DeleteLoggerWithResponse(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*DeleteLoggerResponse, error)

	// GetLoggerWithResponse request
	GetLoggerWithResponse(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*GetLoggerResponse, error)

	// UpdateLoggerWithBodyWithResponse request with any body
	UpdateLoggerWithBodyWithResponse(ctx context.Context, id string, contentType string, body io.Reader, reqEditors ...RequestEditorFn) (*UpdateLoggerResponse, error)

	UpdateLoggerWithApplicationVndAPIPlusJSONBodyWithResponse(ctx context.Context, id string, body UpdateLoggerApplicationVndAPIPlusJSONRequestBody, reqEditors ...RequestEditorFn) (*UpdateLoggerResponse, error)

	// ListLoggerSourcesWithResponse request
	ListLoggerSourcesWithResponse(ctx context.Context, id string, reqEditors ...RequestEditorFn) (*ListLoggerSourcesResponse, error)

	// ListLoggingUsageWithResponse request
	ListLoggingUsageWithResponse(ctx context.Context, params *ListLoggingUsageParams, reqEditors ...RequestEditorFn) (*ListLoggingUsageResponse, error)
}

ClientWithResponsesInterface is the interface specification for the client with responses above.

type CreateLogGroupApplicationVndAPIPlusJSONRequestBody added in v1.3.42

type CreateLogGroupApplicationVndAPIPlusJSONRequestBody = LogGroupResponse

CreateLogGroupApplicationVndAPIPlusJSONRequestBody defines body for CreateLogGroup for application/vnd.api+json ContentType.

type CreateLogGroupResponse added in v1.2.6

type CreateLogGroupResponse struct {
	Body                     []byte
	HTTPResponse             *http.Response
	ApplicationvndApiJSON201 *LogGroupResponse
	ApplicationvndApiJSON400 *ErrorResponse
	ApplicationvndApiJSON401 *ErrorResponse
	ApplicationvndApiJSON404 *ErrorResponse
	ApplicationvndApiJSON429 *ErrorResponse
}

func ParseCreateLogGroupResponse added in v1.2.6

func ParseCreateLogGroupResponse(rsp *http.Response) (*CreateLogGroupResponse, error)

ParseCreateLogGroupResponse parses an HTTP response from a CreateLogGroupWithResponse call

func (CreateLogGroupResponse) Status added in v1.2.6

func (r CreateLogGroupResponse) Status() string

Status returns HTTPResponse.Status

func (CreateLogGroupResponse) StatusCode added in v1.2.6

func (r CreateLogGroupResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type DeleteLogGroupResponse added in v1.2.6

type DeleteLogGroupResponse struct {
	Body                     []byte
	HTTPResponse             *http.Response
	ApplicationvndApiJSON400 *ErrorResponse
	ApplicationvndApiJSON401 *ErrorResponse
	ApplicationvndApiJSON404 *ErrorResponse
	ApplicationvndApiJSON429 *ErrorResponse
}

func ParseDeleteLogGroupResponse added in v1.2.6

func ParseDeleteLogGroupResponse(rsp *http.Response) (*DeleteLogGroupResponse, error)

ParseDeleteLogGroupResponse parses an HTTP response from a DeleteLogGroupWithResponse call

func (DeleteLogGroupResponse) Status added in v1.2.6

func (r DeleteLogGroupResponse) Status() string

Status returns HTTPResponse.Status

func (DeleteLogGroupResponse) StatusCode added in v1.2.6

func (r DeleteLogGroupResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type DeleteLoggerResponse

type DeleteLoggerResponse struct {
	Body                     []byte
	HTTPResponse             *http.Response
	ApplicationvndApiJSON400 *ErrorResponse
	ApplicationvndApiJSON401 *ErrorResponse
	ApplicationvndApiJSON404 *ErrorResponse
	ApplicationvndApiJSON429 *ErrorResponse
}

func ParseDeleteLoggerResponse

func ParseDeleteLoggerResponse(rsp *http.Response) (*DeleteLoggerResponse, error)

ParseDeleteLoggerResponse parses an HTTP response from a DeleteLoggerWithResponse call

func (DeleteLoggerResponse) Status

func (r DeleteLoggerResponse) Status() string

Status returns HTTPResponse.Status

func (DeleteLoggerResponse) StatusCode

func (r DeleteLoggerResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type Error

type Error struct {
	Detail *string                 `json:"detail,omitempty"`
	Source *map[string]interface{} `json:"source,omitempty"`
	Status string                  `json:"status"`
	Title  string                  `json:"title"`
}

Error Single JSON:API error object.

type ErrorResponse

type ErrorResponse struct {
	Errors []Error `json:"errors"`
}

ErrorResponse JSON:API error response envelope.

type GetLogGroupResponse added in v1.2.6

type GetLogGroupResponse struct {
	Body                     []byte
	HTTPResponse             *http.Response
	ApplicationvndApiJSON200 *LogGroupResponse
	ApplicationvndApiJSON400 *ErrorResponse
	ApplicationvndApiJSON401 *ErrorResponse
	ApplicationvndApiJSON404 *ErrorResponse
	ApplicationvndApiJSON429 *ErrorResponse
}

func ParseGetLogGroupResponse added in v1.2.6

func ParseGetLogGroupResponse(rsp *http.Response) (*GetLogGroupResponse, error)

ParseGetLogGroupResponse parses an HTTP response from a GetLogGroupWithResponse call

func (GetLogGroupResponse) Status added in v1.2.6

func (r GetLogGroupResponse) Status() string

Status returns HTTPResponse.Status

func (GetLogGroupResponse) StatusCode added in v1.2.6

func (r GetLogGroupResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type GetLoggerResponse

type GetLoggerResponse struct {
	Body                     []byte
	HTTPResponse             *http.Response
	ApplicationvndApiJSON200 *LoggerResponse
	ApplicationvndApiJSON400 *ErrorResponse
	ApplicationvndApiJSON401 *ErrorResponse
	ApplicationvndApiJSON404 *ErrorResponse
	ApplicationvndApiJSON429 *ErrorResponse
}

func ParseGetLoggerResponse

func ParseGetLoggerResponse(rsp *http.Response) (*GetLoggerResponse, error)

ParseGetLoggerResponse parses an HTTP response from a GetLoggerWithResponse call

func (GetLoggerResponse) Status

func (r GetLoggerResponse) Status() string

Status returns HTTPResponse.Status

func (GetLoggerResponse) StatusCode

func (r GetLoggerResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type HttpRequestDoer

type HttpRequestDoer interface {
	Do(req *http.Request) (*http.Response, error)
}

Doer performs HTTP requests.

The standard http.Client implements this interface.

type ListAllLoggerSourcesParams added in v1.3.42

type ListAllLoggerSourcesParams struct {
	FilterEnvironment *string `form:"filter[environment],omitempty" json:"filter[environment],omitempty"`
	FilterService     *string `form:"filter[service],omitempty" json:"filter[service],omitempty"`
}

ListAllLoggerSourcesParams defines parameters for ListAllLoggerSources.

type ListAllLoggerSourcesResponse added in v1.3.42

type ListAllLoggerSourcesResponse struct {
	Body                     []byte
	HTTPResponse             *http.Response
	ApplicationvndApiJSON200 *LoggerSourceListResponse
	ApplicationvndApiJSON400 *ErrorResponse
	ApplicationvndApiJSON401 *ErrorResponse
	ApplicationvndApiJSON404 *ErrorResponse
	ApplicationvndApiJSON429 *ErrorResponse
}

func ParseListAllLoggerSourcesResponse added in v1.3.42

func ParseListAllLoggerSourcesResponse(rsp *http.Response) (*ListAllLoggerSourcesResponse, error)

ParseListAllLoggerSourcesResponse parses an HTTP response from a ListAllLoggerSourcesWithResponse call

func (ListAllLoggerSourcesResponse) Status added in v1.3.42

Status returns HTTPResponse.Status

func (ListAllLoggerSourcesResponse) StatusCode added in v1.3.42

func (r ListAllLoggerSourcesResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type ListLogGroupsResponse added in v1.2.6

type ListLogGroupsResponse struct {
	Body                     []byte
	HTTPResponse             *http.Response
	ApplicationvndApiJSON200 *LogGroupListResponse
	ApplicationvndApiJSON400 *ErrorResponse
	ApplicationvndApiJSON401 *ErrorResponse
	ApplicationvndApiJSON404 *ErrorResponse
	ApplicationvndApiJSON429 *ErrorResponse
}

func ParseListLogGroupsResponse added in v1.2.6

func ParseListLogGroupsResponse(rsp *http.Response) (*ListLogGroupsResponse, error)

ParseListLogGroupsResponse parses an HTTP response from a ListLogGroupsWithResponse call

func (ListLogGroupsResponse) Status added in v1.2.6

func (r ListLogGroupsResponse) Status() string

Status returns HTTPResponse.Status

func (ListLogGroupsResponse) StatusCode added in v1.2.6

func (r ListLogGroupsResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type ListLoggerSourceServicesResponse added in v1.3.44

type ListLoggerSourceServicesResponse struct {
	Body                     []byte
	HTTPResponse             *http.Response
	ApplicationvndApiJSON200 *LoggerSourceServicesResponse
	ApplicationvndApiJSON400 *ErrorResponse
	ApplicationvndApiJSON401 *ErrorResponse
	ApplicationvndApiJSON404 *ErrorResponse
	ApplicationvndApiJSON429 *ErrorResponse
}

func ParseListLoggerSourceServicesResponse added in v1.3.44

func ParseListLoggerSourceServicesResponse(rsp *http.Response) (*ListLoggerSourceServicesResponse, error)

ParseListLoggerSourceServicesResponse parses an HTTP response from a ListLoggerSourceServicesWithResponse call

func (ListLoggerSourceServicesResponse) Status added in v1.3.44

Status returns HTTPResponse.Status

func (ListLoggerSourceServicesResponse) StatusCode added in v1.3.44

func (r ListLoggerSourceServicesResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type ListLoggerSourcesResponse added in v1.3.42

type ListLoggerSourcesResponse struct {
	Body                     []byte
	HTTPResponse             *http.Response
	ApplicationvndApiJSON200 *LoggerSourceListResponse
	ApplicationvndApiJSON400 *ErrorResponse
	ApplicationvndApiJSON401 *ErrorResponse
	ApplicationvndApiJSON404 *ErrorResponse
	ApplicationvndApiJSON429 *ErrorResponse
}

func ParseListLoggerSourcesResponse added in v1.3.42

func ParseListLoggerSourcesResponse(rsp *http.Response) (*ListLoggerSourcesResponse, error)

ParseListLoggerSourcesResponse parses an HTTP response from a ListLoggerSourcesWithResponse call

func (ListLoggerSourcesResponse) Status added in v1.3.42

func (r ListLoggerSourcesResponse) Status() string

Status returns HTTPResponse.Status

func (ListLoggerSourcesResponse) StatusCode added in v1.3.42

func (r ListLoggerSourcesResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type ListLoggersParams

type ListLoggersParams struct {
	FilterManaged  *bool   `form:"filter[managed],omitempty" json:"filter[managed],omitempty"`
	FilterService  *string `form:"filter[service],omitempty" json:"filter[service],omitempty"`
	FilterLastSeen *string `form:"filter[last_seen],omitempty" json:"filter[last_seen],omitempty"`
}

ListLoggersParams defines parameters for ListLoggers.

type ListLoggersResponse

type ListLoggersResponse struct {
	Body                     []byte
	HTTPResponse             *http.Response
	ApplicationvndApiJSON200 *LoggerListResponse
	ApplicationvndApiJSON400 *ErrorResponse
	ApplicationvndApiJSON401 *ErrorResponse
	ApplicationvndApiJSON404 *ErrorResponse
	ApplicationvndApiJSON429 *ErrorResponse
}

func ParseListLoggersResponse

func ParseListLoggersResponse(rsp *http.Response) (*ListLoggersResponse, error)

ParseListLoggersResponse parses an HTTP response from a ListLoggersWithResponse call

func (ListLoggersResponse) Status

func (r ListLoggersResponse) Status() string

Status returns HTTPResponse.Status

func (ListLoggersResponse) StatusCode

func (r ListLoggersResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type ListLoggingUsageParams added in v1.3.42

type ListLoggingUsageParams struct {
	FilterPeriod *string `form:"filter[period],omitempty" json:"filter[period],omitempty"`
}

ListLoggingUsageParams defines parameters for ListLoggingUsage.

type ListLoggingUsageResponse added in v1.3.42

type ListLoggingUsageResponse struct {
	Body                     []byte
	HTTPResponse             *http.Response
	ApplicationvndApiJSON200 *UsageListResponse
	ApplicationvndApiJSON400 *ErrorResponse
	ApplicationvndApiJSON401 *ErrorResponse
	ApplicationvndApiJSON404 *ErrorResponse
	ApplicationvndApiJSON429 *ErrorResponse
}

func ParseListLoggingUsageResponse added in v1.3.42

func ParseListLoggingUsageResponse(rsp *http.Response) (*ListLoggingUsageResponse, error)

ParseListLoggingUsageResponse parses an HTTP response from a ListLoggingUsageWithResponse call

func (ListLoggingUsageResponse) Status added in v1.3.42

func (r ListLoggingUsageResponse) Status() string

Status returns HTTPResponse.Status

func (ListLoggingUsageResponse) StatusCode added in v1.3.42

func (r ListLoggingUsageResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type LogGroup added in v1.2.6

type LogGroup struct {
	CreatedAt    *time.Time              `json:"created_at,omitempty"`
	Environments *map[string]interface{} `json:"environments,omitempty"`
	Key          *string                 `json:"key,omitempty"`
	Level        *string                 `json:"level,omitempty"`
	Name         string                  `json:"name"`
	ParentId     *string                 `json:"parent_id,omitempty"`
	UpdatedAt    *time.Time              `json:"updated_at,omitempty"`
}

LogGroup defines model for LogGroup.

type LogGroupListResponse added in v1.2.6

type LogGroupListResponse struct {
	Data []LogGroupResource `json:"data"`
}

LogGroupListResponse defines model for LogGroupListResponse.

type LogGroupResource added in v1.2.6

type LogGroupResource struct {
	Attributes LogGroup             `json:"attributes"`
	Id         *string              `json:"id,omitempty"`
	Type       LogGroupResourceType `json:"type"`
}

LogGroupResource defines model for LogGroupResource.

type LogGroupResourceType added in v1.2.6

type LogGroupResourceType string

LogGroupResourceType defines model for LogGroupResource.Type.

const (
	LogGroupResourceTypeLogGroup LogGroupResourceType = "log_group"
)

Defines values for LogGroupResourceType.

func (LogGroupResourceType) Valid added in v1.2.6

func (e LogGroupResourceType) Valid() bool

Valid indicates whether the value is a known member of the LogGroupResourceType enum.

type LogGroupResponse added in v1.2.6

type LogGroupResponse struct {
	Data LogGroupResource `json:"data"`
}

LogGroupResponse defines model for LogGroupResponse.

type Logger

type Logger struct {
	CreatedAt       *time.Time                `json:"created_at,omitempty"`
	EffectiveLevels *map[string]interface{}   `json:"effective_levels,omitempty"`
	Environments    *map[string]interface{}   `json:"environments,omitempty"`
	Group           *string                   `json:"group,omitempty"`
	Level           *string                   `json:"level,omitempty"`
	Managed         *bool                     `json:"managed,omitempty"`
	Name            string                    `json:"name"`
	Sources         *[]map[string]interface{} `json:"sources,omitempty"`
	UpdatedAt       *time.Time                `json:"updated_at,omitempty"`
}

Logger defines model for Logger.

type LoggerBulkItem added in v1.2.6

type LoggerBulkItem struct {
	// Environment Environment where this logger was observed
	Environment *string `json:"environment,omitempty"`

	// Id Normalized logger name
	Id string `json:"id"`

	// Level The explicitly-set level on this logger. Null if inherited.
	Level *string `json:"level,omitempty"`

	// ResolvedLevel The effective level after framework inheritance. Never null in compliant SDKs.
	ResolvedLevel *string `json:"resolved_level,omitempty"`

	// Service Service name that discovered this logger
	Service *string `json:"service,omitempty"`
}

LoggerBulkItem defines model for LoggerBulkItem.

type LoggerBulkRequest added in v1.2.6

type LoggerBulkRequest struct {
	Loggers []LoggerBulkItem `json:"loggers"`
}

LoggerBulkRequest defines model for LoggerBulkRequest.

type LoggerBulkResponse added in v1.2.6

type LoggerBulkResponse struct {
	Registered int `json:"registered"`
}

LoggerBulkResponse defines model for LoggerBulkResponse.

type LoggerListResponse

type LoggerListResponse struct {
	Data []LoggerResource `json:"data"`
}

LoggerListResponse defines model for LoggerListResponse.

type LoggerResource

type LoggerResource struct {
	Attributes Logger             `json:"attributes"`
	Id         *string            `json:"id,omitempty"`
	Type       LoggerResourceType `json:"type"`
}

LoggerResource defines model for LoggerResource.

type LoggerResourceType added in v1.2.6

type LoggerResourceType string

LoggerResourceType defines model for LoggerResource.Type.

const (
	LoggerResourceTypeLogger LoggerResourceType = "logger"
)

Defines values for LoggerResourceType.

func (LoggerResourceType) Valid added in v1.2.6

func (e LoggerResourceType) Valid() bool

Valid indicates whether the value is a known member of the LoggerResourceType enum.

type LoggerResponse

type LoggerResponse struct {
	Data LoggerResource `json:"data"`
}

LoggerResponse defines model for LoggerResponse.

type LoggerSource added in v1.3.42

type LoggerSource struct {
	CreatedAt     *time.Time `json:"created_at,omitempty"`
	Environment   *string    `json:"environment,omitempty"`
	FirstObserved *time.Time `json:"first_observed,omitempty"`
	LastSeen      *time.Time `json:"last_seen,omitempty"`
	Level         *string    `json:"level,omitempty"`
	ResolvedLevel *string    `json:"resolved_level,omitempty"`
	Service       *string    `json:"service,omitempty"`
	UpdatedAt     *time.Time `json:"updated_at,omitempty"`
}

LoggerSource defines model for LoggerSource.

type LoggerSourceListResponse added in v1.3.42

type LoggerSourceListResponse struct {
	Data []LoggerSourceResource `json:"data"`
}

LoggerSourceListResponse defines model for LoggerSourceListResponse.

type LoggerSourceResource added in v1.3.42

type LoggerSourceResource struct {
	Attributes LoggerSource             `json:"attributes"`
	Id         *string                  `json:"id,omitempty"`
	Type       LoggerSourceResourceType `json:"type"`
}

LoggerSourceResource defines model for LoggerSourceResource.

type LoggerSourceResourceType added in v1.3.42

type LoggerSourceResourceType string

LoggerSourceResourceType defines model for LoggerSourceResource.Type.

const (
	LoggerSourceResourceTypeLoggerSource LoggerSourceResourceType = "logger_source"
)

Defines values for LoggerSourceResourceType.

func (LoggerSourceResourceType) Valid added in v1.3.42

func (e LoggerSourceResourceType) Valid() bool

Valid indicates whether the value is a known member of the LoggerSourceResourceType enum.

type LoggerSourceServicesResponse added in v1.3.44

type LoggerSourceServicesResponse struct {
	Services []string `json:"services"`
}

LoggerSourceServicesResponse defines model for LoggerSourceServicesResponse.

type RequestEditorFn

type RequestEditorFn func(ctx context.Context, req *http.Request) error

RequestEditorFn is the function signature for the RequestEditor callback function

type UpdateLogGroupApplicationVndAPIPlusJSONRequestBody added in v1.3.42

type UpdateLogGroupApplicationVndAPIPlusJSONRequestBody = LogGroupResponse

UpdateLogGroupApplicationVndAPIPlusJSONRequestBody defines body for UpdateLogGroup for application/vnd.api+json ContentType.

type UpdateLogGroupResponse added in v1.2.6

type UpdateLogGroupResponse struct {
	Body                     []byte
	HTTPResponse             *http.Response
	ApplicationvndApiJSON200 *LogGroupResponse
	ApplicationvndApiJSON400 *ErrorResponse
	ApplicationvndApiJSON401 *ErrorResponse
	ApplicationvndApiJSON404 *ErrorResponse
	ApplicationvndApiJSON429 *ErrorResponse
}

func ParseUpdateLogGroupResponse added in v1.2.6

func ParseUpdateLogGroupResponse(rsp *http.Response) (*UpdateLogGroupResponse, error)

ParseUpdateLogGroupResponse parses an HTTP response from a UpdateLogGroupWithResponse call

func (UpdateLogGroupResponse) Status added in v1.2.6

func (r UpdateLogGroupResponse) Status() string

Status returns HTTPResponse.Status

func (UpdateLogGroupResponse) StatusCode added in v1.2.6

func (r UpdateLogGroupResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type UpdateLoggerApplicationVndAPIPlusJSONRequestBody added in v1.3.42

type UpdateLoggerApplicationVndAPIPlusJSONRequestBody = LoggerResponse

UpdateLoggerApplicationVndAPIPlusJSONRequestBody defines body for UpdateLogger for application/vnd.api+json ContentType.

type UpdateLoggerResponse

type UpdateLoggerResponse struct {
	Body                     []byte
	HTTPResponse             *http.Response
	ApplicationvndApiJSON200 *LoggerResponse
	ApplicationvndApiJSON400 *ErrorResponse
	ApplicationvndApiJSON401 *ErrorResponse
	ApplicationvndApiJSON404 *ErrorResponse
	ApplicationvndApiJSON429 *ErrorResponse
}

func ParseUpdateLoggerResponse

func ParseUpdateLoggerResponse(rsp *http.Response) (*UpdateLoggerResponse, error)

ParseUpdateLoggerResponse parses an HTTP response from a UpdateLoggerWithResponse call

func (UpdateLoggerResponse) Status

func (r UpdateLoggerResponse) Status() string

Status returns HTTPResponse.Status

func (UpdateLoggerResponse) StatusCode

func (r UpdateLoggerResponse) StatusCode() int

StatusCode returns HTTPResponse.StatusCode

type UsageAttributes added in v1.3.42

type UsageAttributes struct {
	LimitKey string `json:"limit_key"`
	Period   string `json:"period"`
	Value    int    `json:"value"`
}

UsageAttributes defines model for UsageAttributes.

type UsageListResponse added in v1.3.42

type UsageListResponse struct {
	Data []UsageResource `json:"data"`
}

UsageListResponse defines model for UsageListResponse.

type UsageResource added in v1.3.42

type UsageResource struct {
	Attributes UsageAttributes   `json:"attributes"`
	Id         string            `json:"id"`
	Type       UsageResourceType `json:"type"`
}

UsageResource defines model for UsageResource.

type UsageResourceType added in v1.3.42

type UsageResourceType string

UsageResourceType defines model for UsageResource.Type.

const (
	Usage UsageResourceType = "usage"
)

Defines values for UsageResourceType.

func (UsageResourceType) Valid added in v1.3.42

func (e UsageResourceType) Valid() bool

Valid indicates whether the value is a known member of the UsageResourceType enum.

Jump to